@@ -7,26 +7,36 @@ from to_log import Logger
 import configparser
 import socket
 
-import redis
-
 __all__ = [
-    'API_REGISTRY',
+    'ADDRESS',
+    'APIGW',
     'CONFIG',
     'LOGS',
     'HOSTNAME',
-    'SERVICE_CODE'
+    'SERVICE_CODE',
+    'SMPP_ACCOUNTS'
     ]
 
 CONFIG = configparser.ConfigParser(allow_no_value=True)
 CONFIG.read('/etc/smsc-services/smsc-services.conf')
 
 SERVICE_CODE = CONFIG['APP']['service_code']
-
 HOSTNAME = socket.gethostname().split('.')[0]
-API_REGISTRY = redis.Redis(db=15)
+_socket = socket.socket(socket.AF_INET, socket.SOCK_DGRAM)
+_socket.connect(("41.204.103.205", 80))
+ADDRESS = _socket.getsockname()[0]
+if HOSTNAME.startswith('bldv'):
+    APIGW = 'bldv040v.blueline.mg'
+elif HOSTNAME.startswith('blst'):
+    APIGW = 'blst040v.blueline.mg'
+else:
+    APIGW = 'api.blueline.mg'
 
-if HOSTNAME.startswith('blpr'):
-    API_REGISTRY = redis.Redis(host='api.blueline.mg', db=15)
+SMPP_ACCOUNTS = [
+    i.replace('SMPP_', '')
+    for i in CONFIG.sections()
+    if i.startswith('SMPP_')
+    ]
 
 LOG_LEVEL = CONFIG['LOGS']['level']
 LOG_FILE = CONFIG['LOGS']['filename']
